==> angelscript_2.31.2.zip: sdk/docs/manual/doc_addon_application.js <==
var doc_addon_application =
[
    [ "Script builder", "doc_addon_build.html", [
      [ "Public C++ interface", "doc_addon_build.html#doc_addon_build_1", [
        [ "The include callback signature", "doc_addon_build.html#doc_addon_build_1_1", null ]
      ] ],
      [ "Include directives", "doc_addon_build.html#doc_addon_build_2", null ],
      [ "Conditional programming", "doc_addon_build.html#doc_addon_build_condition", null ],
      [ "Metadata in scripts", "doc_addon_build.html#doc_addon_build_metadata", null ]
    ] ],
    [ "Context manager", "doc_addon_ctxmgr.html", [
      [ "Public C++ interface", "doc_addon_ctxmgr.html#doc_addon_ctxmgr_1", null ],
      [ "Public script interface", "doc_addon_ctxmgr.html#doc_addon_ctxmgr_2", null ]
    ] ],
    [ "Debugger", "doc_addon_debugger.html", [
      [ "Public C++ interface", "doc_addon_debugger.html#doc_addon_ctxmgr_1", null ],
      [ "Example usage", "doc_addon_debugger.html#doc_addon_debugger_1", null ]
    ] ],
    [ "Serializer", "doc_addon_serializer.html", [
      [ "Public C++ interface", "doc_addon_serializer.html#doc_addon_serializer_1", null ],
      [ "Example usage", "doc_addon_serializer.html#doc_addon_serializer_2", null ]
    ] ],
    [ "Helper functions", "doc_addon_helpers.html", [
      [ "Public C++ interface", "doc_addon_helpers.html#doc_addon_helpers_1", null ],
      [ "Example", "doc_addon_helpers.html#doc_addon_helpers_2", null ]
    ] ],
    [ "Automatic wrapper functions", "doc_addon_autowrap.html", [
      [ "Example usage", "doc_addon_autowrap.html#doc_addon_autowrap_1", null ],
      [ "Adding support for more parameters", "doc_addon_autowrap.html#doc_addon_autowrap_2", null ]
    ] ]
];

==> angelscript_2.33.0.zip: sdk/docs/manual/doc_addon_application.js <==
var doc_addon_application =
[
    [ "Script builder", "doc_addon_build.html", [
      [ "Public C++ interface", "doc_addon_build.html#doc_addon_build_1", [
        [ "The include callback signature", "doc_addon_build.html#doc_addon_build_1_1", null ],
        [ "The pragma callback signature", "doc_addon_build.html#doc_addon_build_1_2", null ]
      ] ],
      [ "Include directives", "doc_addon_build.html#doc_addon_build_2", null ],
      [ "Conditional programming", "doc_addon_build.html#doc_addon_build_condition", null ],
      [ "Metadata in scripts", "doc_addon_build.html#doc_addon_build_metadata", null ]
    ] ],
    [ "Context manager", "doc_addon_ctxmgr.html", [
      [ "Public C++ interface", "doc_addon_ctxmgr.html#doc_addon_ctxmgr_1", null ],
      [ "Public script interface", "doc_addon_ctxmgr.html#doc_addon_ctxmgr_2", null ]
    ] ],
    [ "Debugger", "doc_addon_debugger.html", [
      [ "Public C++ interface", "doc_addon_debugger.html#doc_addon_ctxmgr_1", null ],
      [ "Example usage", "doc_addon_debugger.html#doc_addon_debugger_1", null ]
    ] ],
    [ "Serializer", "doc_addon_serializer.html", [
      [ "Public C++ interface", "doc_addon_serializer.html#doc_addon_serializer_1", null ],
      [ "Example usage", "doc_addon_serializer.html#doc_addon_serializer_2", null ]
    ] ],
    [ "Helper functions", "doc_addon_helpers.html", [
      [ "Public C++ interface", "doc_addon_helpers.html#doc_addon_helpers_1", null ],
      [ "Example", "doc_addon_helpers.html#doc_addon_helpers_2", null ]
    ] ],
    [ "Automatic wrapper functions", "doc_addon_autowrap.html", [
      [ "Example usage", "doc_addon_autowrap.html#doc_addon_autowrap_1", null ],
      [ "Adding support for more parameters", "doc_addon_autowrap.html#doc_addon_autowrap_2", null ]
    ] ]
];
